@@ -3,7 +3,7 @@ Single-threaded job queue. This should be turned into a parallel job queue at so
 """
 class JobQueue:
     def __init__(self, name=None, parent=None) -> None:
-        self.name = name if name else ""
+        self.name = name
         self.parent = parent
         self.waited = False
         self.subs = []
@@ -16,13 +16,17 @@ class JobQueue:
             print(f'X[{self._name()}]: Failed to print logs!', flush=True)
 
     def submit(self, name, job):
+        if name is None and self.name is not None:
+            raise Exception('Queue must have a name if parent queue has a name')
         sub = JobQueue(name=name, parent=self)
         self.subs.append(sub)
         job(sub)
-        for level, msg in sub.logs:
-            print(f'{level}[{sub._name()}]: {msg}', flush=True)
-        sub.logs = []
-        pass
+        sub.flush_logs()
+
+    def flush_logs(self):
+        for level, msg in self.logs:
+            print(f'{level}[{self._name()}]: {msg}', flush=True)
+        self.logs = []
 
     def error(self, msg):
         self._log("E", msg)
@@ -38,9 +42,12 @@ class JobQueue:
 
     def wait(self):
         self.waited = True
-        pass
+
+    def is_root(self):
+        return self.parent is None or self.name is None
 
     def _name(self):
-        if self.parent:
+        if self.is_root():
+            return '(root)'
+        else:
             return f'{self.parent._name()}/{self.name}'
-        return self.name
