@@ -2,11 +2,15 @@ from abc import abstractmethod
 
 class Operation:
     @abstractmethod
-    def operate(dir, files):
+    def operate(self, q, dir, files):
         pass
 
-class PrintFilesOperation:
-    def operate(self, q, dir, files):
+    @abstractmethod
+    def initialize(self, q, dir):
+        pass
+
+class PrintFilesOperation(Operation):
+    def operate(self, q, _, files):
         q.info(f"{len(files)} file(s)")
         for file in files:
             q.info(f"  {file.name}")
